[clang] 8e0715e - Change a test case to be more generic; NFC

Aaron Ballman via cfe-commits cfe-commits at lists.llvm.org
Thu Jul 20 10:29:11 PDT 2023


Author: Aaron Ballman
Date: 2023-07-20T13:29:01-04:00
New Revision: 8e0715e40e43aaadc5a9d3fdd0678e4474fe463b

URL: https://github.com/llvm/llvm-project/commit/8e0715e40e43aaadc5a9d3fdd0678e4474fe463b
DIFF: https://github.com/llvm/llvm-project/commit/8e0715e40e43aaadc5a9d3fdd0678e4474fe463b.diff

LOG: Change a test case to be more generic; NFC

This amends 4a100690461022625dc5d2a21e2e028a926149d9 to address the
issue found by:
https://lab.llvm.org/buildbot/#/builders/188/builds/32658

Added: 
    

Modified: 
    clang/test/SemaCXX/builtins.cpp

Removed: 
    


################################################################################
diff  --git a/clang/test/SemaCXX/builtins.cpp b/clang/test/SemaCXX/builtins.cpp
index af6e565100aaeb..eef0fabf67717b 100644
--- a/clang/test/SemaCXX/builtins.cpp
+++ b/clang/test/SemaCXX/builtins.cpp
@@ -166,6 +166,8 @@ template void test_builtin_complex(double, double);
 template void test_builtin_complex(float, double); // expected-note {{instantiation of}}
 template void test_builtin_complex(int, double); // expected-note {{instantiation of}}
 
+#ifdef __x86_64__
 // This previously would cause an assertion when emitting the note diagnostic.
-static void _mm_sfence(); // expected-error {{static declaration of '_mm_sfence' follows non-static declaration}} \
-                             expected-note {{'_mm_sfence' is a builtin with type 'void () noexcept'}}
+static void __builtin_cpu_init(); // expected-error {{static declaration of '__builtin_cpu_init' follows non-static declaration}} \
+                                     expected-note {{'__builtin_cpu_init' is a builtin with type 'void () noexcept'}}
+#endif


        


More information about the cfe-commits mailing list